@@ -7,14 +7,14 @@ use warnings;
 use Scalar::Util qw/reftype refaddr/;
 use Encode qw/decode encode/;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our (%HELP, @MAYBE, $caller, $destruct);
 BEGIN {
 	%HELP = (
 		arrayref => sub { return map { $_[0]->($_, $_[2]) } @{ $_[1] } },
 		hashref => sub { $caller->can('filter_keys') && $caller->filter_keys($_[1]->{$_}, $_) and next or 
 			$destruct && do { $_[3]{$_[0]->($_)} = $_[0]->($_[1]->{$_}, $_[2]) } || do { $_[1]->{$_} = $_[0]->($_[1]->{$_}, $_[2]) } for keys %{ $_[1] }; $_[3]; },
-		scalarref => sub { my $s = $_[1]; ${$s} =~ m/^[0-9.]+$/g ? $s : do { $s = scalar $_[0]->(${$s}); $s = $destruct ? $s : \ scalar $s; } && $s },
+		scalarref => sub { my $s = $_[1]; ${$s} =~ m/^[0-9.]+$/g ? $s : do { $s = $_[0]->(${$s}); $destruct ? $s : \$s; } }, 
 		scalar => sub { eval { $_[1] = $_[0]->($_, $_[1], Encode::FB_CROAK); 1; } and last foreach @MAYBE; $_[1]; }
 	);
 }
@@ -70,7 +70,7 @@ Struct::WOP - deeply encode/decode a struct
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
